miniwdl
=======

`miniwdl <https://github.com/chanzuckerberg/miniwdl/>`_ is a local runner and developer toolkit for
the bioinformatics-focused `Workflow Description Language (WDL) <http://openwdl.org/>`_. 

.. toctree::
   :maxdepth: 2

   getting_started.md
   runner_cli.rst
   runner_reference.md
   runner_advanced.md
   runner_backends.md
   check.rst
   zip.rst
   FAQ.md
   WDL.rst

Links
=====

* `miniwdl repo <https://github.com/chanzuckerberg/miniwdl/>`_ for installation instructions & issue
  tracker
* `OpenWDL repo <https://github.com/openwdl/wdl>`_ for WDL spec, proposals, and discussion
* `CZI Science Technology <https://chanzuckerberg.com/technology/science/>`_ sponsors this project

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
